@@ -69,7 +69,6 @@ import calendar
 _logfile_name = None
 _logfile = None
 
-#_string_encoding = None
 
 # table used for cooking non-printables
 AsciiName = ['<#0-0x00-nul>',
@@ -141,7 +140,11 @@ def log_instance_state(instance):
 	logger = logging.getLogger('gm.logging')
 	logger.debug('state of %s', instance)
 	for attr in [ a for a in dir(instance) if not a.startswith('__') ]:
-		logger.debug('  %s: %s', attr, getattr(instance, attr))
+		try:
+			val = getattr(instance, attr)
+		except AttributeError:
+			val = '<cannot access>'
+		logger.debug('  %s: %s', attr, val)
 
 #===============================================================
 def log_stack_trace(message=None, t=None, v=None, tb=None):
@@ -167,7 +170,11 @@ def log_stack_trace(message=None, t=None, v=None, tb=None):
 	logger.debug('type: %s', t)
 	logger.debug('list of attributes:')
 	for attr in [ a for a in dir(v) if not a.startswith('__') ]:
-		logger.debug('  %s: %s', attr, getattr(v, attr))
+		try:
+			val = getattr(v, attr)
+		except AttributeError:
+			val = '<cannot access>'
+		logger.debug('  %s: %s', attr, val)
 
 	# make sure we don't leave behind a binding
 	# to the traceback as warned against in
@@ -219,6 +226,20 @@ def log_multiline(level, message=None, line_prefix=None, text=None):
 	logger = logging.getLogger('gm.logging')
 	logger.log(level, '\n'.join(lines2log))
 
+#---------------------------------------------------------------
+__current_log_step = 1
+
+def log_step(level:int=logging.DEBUG, message:str=None, restart:bool=False):
+	if restart:
+		global __current_log_step
+		__current_log_step = 1
+	logger = logging.getLogger('gm.logging')
+	if message:
+		logger.log(level, '%s - %s', __current_log_step, message)
+	else:
+		logger.log(level, '%s', __current_log_step)
+	__current_log_step += 1
+
 #===============================================================
 # internal API
 #===============================================================
@@ -338,19 +359,24 @@ if __name__ == '__main__':
 
 	#-----------------------------------------------------------
 	def test():
+		print(_logfile_name)
+		log_step(message = 'testing')
 		logger = logging.getLogger('gmLog2.test')
-
+		log_step()
 		logger.error('test %s', [1,2,3])
-
+		log_step(message = 'still testing')
 		logger.error("I expected to see %s::test()" % __file__)
+		log_step(message = 'restarting', restart = True)
 		add_word2hide('super secret passphrase')
+		log_step()
 		logger.debug('credentials: super secret passphrase')
-
+		log_step()
 		try:
 			int(None)
 		except Exception:
 			logger.exception('unhandled exception')
 			log_stack_trace()
 		flush()
+		log_step(message = 'done')
 	#-----------------------------------------------------------
 	test()
